# Idea

## backlog
- [ ] user can generate nodes/edges manually and connect to generated ones
    - [ ] eg: add owner
    - [ ] add extra info for schema
- [ ] optimize static resource (allow manually config url)
- [ ] improve search dialog
    - [ ] add route/tag list
- [ ] type alias should not be kept as node instead of compiling to original type
- [ ] how to correctly handle the generic type ?
- [ ] support Google analysis config
- [ ] sort field name in nodes (only table inside right panel), pending
- [ ] set max limit for fields in nodes

## in analysis
- [ ] upgrade network algorithm (optional)
- [ ] click field to highlight links
- [ ] animation effect for edges
- [ ] display standard ER diagram spec. `hard but important`
    - [ ] display potential invalid links
    - [ ] highlight relationship belongs to ER diagram